# Installation

PyXIRR doesn't have external dependencies.

```bash
pip install pyxirr
```


## Installation from source

To install PyXIRR from source you need [Rust](https://www.rust-lang.org) version 1.41 or higher.
Supported python versions depends on [pyo3](https://github.com/PyO3/pyo3) which supports Python 3.6 and up.

Thanks to [PEP-517](https://www.python.org/dev/peps/pep-0517/) and [maturin](https://github.com/PyO3/maturin), installation from source as simple as

```bash
pip install path/to/pyxirr
```
